@@ -1,5 +1,8 @@
 from ._models import (
     LinearElastic,
+    LinearElasticTensorNotation,
+    LinearElasticPlaneStress,
+    LinearElasticPlaneStrain,
     NeoHooke,
 )
 
