@@ -395,7 +395,11 @@ def add_midpoints_edges(points, cells, cell_type):
     }
 
     # collect edges
-    points_edges, cells_edges = collect_edges(points, cells, cell_type,)
+    points_edges, cells_edges = collect_edges(
+        points,
+        cells,
+        cell_type,
+    )
 
     # add offset to point index for edge-midpoints
     # in additional cells array
@@ -424,7 +428,11 @@ def add_midpoints_faces(points, cells, cell_type):
     }
 
     # collect faces
-    points_faces, cells_faces = collect_faces(points, cells, cell_type,)
+    points_faces, cells_faces = collect_faces(
+        points,
+        cells,
+        cell_type,
+    )
 
     # add offset to point index for faces-midpoints
     # in additional cells array
@@ -452,7 +460,11 @@ def add_midpoints_volumes(points, cells, cell_type):
     }
 
     # collect volumes
-    points_volumes, cells_volumes = collect_volumes(points, cells, cell_type,)
+    points_volumes, cells_volumes = collect_volumes(
+        points,
+        cells,
+        cell_type,
+    )
 
     # add offset to point index for volumes-midpoints
     # in additional cells array
